NUMBER_MAPPING = {
    "0": "không",
    "1": "một",
    "2": "hai",
    "3": "ba",
    "4": "bốn",
    "5": "năm",
    "6": "sáu",
    "7": "bảy",
    "8": "tám",
    "9": "chín",
    ",": "phẩy",
}

NUMBER_UNIT_SINGLE = ["", "mươi", "trăm"]

NUMBER_UNIT_TRIPLE = ["", "nghìn", "triệu", "tỷ", "nghìn tỷ", "triệu tỷ", "tỷ tỷ"]

SEQUENCE_PHONES_VI_MAPPING = {
    "a": "a",
    "ă": "á",
    "â": "ớ",
    "b": "bê",
    "c": "xê",
    "d": "đê",
    "đ": "đê",
    "e": "e",
    "ê": "ê",
    "f": "ép",
    "g": "gờ",
    "h": "hát",
    "i": "i",
    "j": "di",
    "k": "ca",
    "l": "lờ",
    "m": "mờ",
    "n": "nờ",
    "o": "o",
    "ô": "ô",
    "ơ": "ơ",
    "p": "pê",
    "q": "quy",
    "r": "rờ",
    "s": "ét",
    "t": "tê",
    "u": "u",
    "ư": "ư",
    "v": "vê",
    "w": "vê kép",
    "x": "ích",
    "y": "y",
    "z": "dét",
    "+": "cộng",
    ".": "chấm",
    "=": "bằng",
    "-": "gạch ngang",
    "&": "và",
    "*": "sao",
    "^": "mũ",
    "~": "ngã",
    "!": "chấm than",
    "?": "chấm hỏi",
    "@": "a còng",
    "#": "thăng",
    "$": "đô la",
    "%": "phần trăm",
    ">": "dấu lớn",
    "<": "dấu bé",
    ":": "hai chấm",
    ";": "chấm phẩy",
    "/": "gạch chéo",
    "\\": "gạch chéo ngược",
    "±": "cộng trừ",
}

SEQUENCE_PHONES_EN_MAPPING = {
    "a": "ây",
    "b": "bi",
    "c": "xi",
    "d": "đi",
    "e": "i",
    "f": "ép",
    "g": "chi",
    "h": "ếch",
    "i": "ai",
    "j": "chây",
    "k": "cây",
    "l": "eo",
    "m": "em",
    "n": "en",
    "o": "âu",
    "p": "pi",
    "q": "kiu",
    "r": "a",
    "s": "ét",
    "t": "ti",
    "u": "du",
    "v": "vi",
    "w": "đáp du",
    "x": "ách",
    "y": "oai",
    "z": "di",
    "+": "pờ lớt",
    ".": "đót",
    "=": "i quờ",
    "-": "hai phừn",
    "&": "en",
    "*": "át te rích",
    "^": "ke rớt",
    "~": "tiu đờ",
    "!": "ích cờ lêm mây sừn mác",
    "?": "quét chừn mác",
    "@": "át",
    "#": "hát sờ",
    "$": "đo lờ",
    "%": "bơ sen",
    ">": "mo dan",
    "<": "lét dan",
    ":": "co lừn",
    ";": "se mi co lừn",
    "/": "sờ lát",
    "\\": "bách sờ lát",
    "±": "pờ lớt mai nớt",
}

MONEY_UNITS_MAPPING = {
    "$": "đô la",
    "€": "ơ rô",
    "¥": "yên",
    "₫": "đồng",
    "đ": "đồng",
    "฿": "bạt",
    "₭": "kíp",
    "₹": "rúp",
    "₽": "rúp",
    "₱": "pê sô",
    "£": "bảng anh",
    "₩": "won",
}

MEASUREMENT_UNITS_MAPPING = {
    "%": "phần trăm",
    "K": "ca",
    "k": "ca",
    "Mbps": "mê ga bít trên giây",
    "bit/s": "bít trên giây",
    "bit": "bít",
    "kilowatt": "ki lô oát",
    "km/h": "ki lô mét trên giờ",
    "kV": "ki lô vôn",
    "KV": "ki lô vôn",
    "V": "vôn",
    "volt": "vôn",
    "kWh": "ki lô oát giờ",
    "MW": "mê ga oát",
    "mAh": "mi li am pe giờ",
    "nm": "na nô mét",
    "Nm": "niu tơn mét",
    "um": "mi cờ rô mét",
    "mm": "mi li mét",
    "milimét": "mi li mét",
    "cm": "xen ti mét",
    "cm2": "xen ti mét vuông",
    "cm3": "xen ti mét khối",
    "dm": "đề xi mét",
    "m": "mét",
    "met": "mét",
    "m3": "mét khối",
    "m2": "mét vuông",
    "ml": "mi li lít",
    "l": "lít",
    "km": "ki lô mét",
    "km2": "ki lô mét vuông",
    "m/s": "mét trên giây",
    "kg": "ki lô gam",
    "mg": "mi li gam",
    "g": "gam",
    "gram": "gam",
    "gr": "gam",
    "h": "giờ",
    "px": "pích xeo",
    "MP": "mê ga pích xeo",
    "inch": "inh",
    "ha": "héc ta",
    "hecta": "héc ta",
    "MHz": "mê ga héc",
    "°": "độ",
    "°C": "độ xê",
    "°F": "độ ép",
    "⁰": "độ",
    "⁰C": "độ xê",
    "⁰F": "độ ép",
    "Mb": "mê ga bít",
    "MB": "mê ga bai",
    "GB": "ghi ga bai",
    "amp": "am pe",
    "′": "phút",
    "″": "giây",
    "s": "giây",
    "cara": "ca ra",
    "kilô": "ki lô",
    "dB": "đề xi ben",
    "dBA": "đề xi ben a",
    "mg/l": "mi li gam trên lít",
    "USD": "u ét đê",
    "Bq": "béc cơ ren",
    "Cal": "ca lo",
    "GHz": "ghi ga héc",
    "GN": "ghi ga niu tơn",
    "GW": "ghi ga oát",
    "Hz": "héc",
    "J": "giun",
    "Kcal": "ki lô ca lo",
    "Kn": "ki lô niu tơn",
    "MJ": "mê ga giun",
    "MN": "mê ga niu tơn",
    "MWh": "mê ga oát giờ",
    "MeV": "mê ga e léc tron vôn",
    "N": "niu tơn",
    "Pa": "bát can",
    "TB": "tê ra bai",
    "THz": "tê ra héc",
    "W": "oát",
    "Wb": "ve bê",
    "Wh": "oát giờ",
    "ampe": "am be",
    "at": "át mốt phe",
    "atm": "át mốt phe",
    "carat": "ca ra",
    "cd": "can đê la",
    "dm2": "đề xi mét vuông",
    "dm3": "đề xi mét khối",
    "dp": "đi ốp",
    "eV": "e léc tron vôn",
    "ft": "phít",
    "gal": "ga lon",
    "gallon": "ga lon",
    "gj": "ghi ga giun",
    "hz": "héc",
    "j": "giun",
    "kB": "ki lô bai",
    "kHz": "ki lô héc",
    "kJ": "ki lô giun",
    "kN": "ki lô niu tơn",
    "kW": "ki lô oát",
    "kWp": "ki lô oát bích",
    "kb": "ki lô bít",
    "kcal": "ki lô ca lo",
    "kj": "ki lô giun",
    "km3": "ki lô mét khối",
    "kv": "ki lô vôn",
    "lb": "pao",
    "µm": "mi cờ rô mét",
    "mJ": "mi li giun",
    "mL": "mi li lít",
    "mN": "mi li niu tơn",
    "mb": "mê ga bít",
    "mbps": "mê ga bít trên giây",
    "mj": "mê ga giun",
    "mm2": "mi li mét vuông",
    "mm3": "mi li mét khối",
    "mmHg": "mi li mét thuỷ ngân",
    "mol": "mon",
    "mw": "mê ga oát",
    "ounce": "ao",
    "oz": "ao",
    "pound": "pao",
    "rad": "ra đi an",
    "s2": "giây bình phương",
    "sec": "giây",
    "vg": "vòng",
    "w": "oát",
    "µg": "mi cờ rô gam",
    "điôp": "đi ốp",
    "Ω": "ôm",
    "μ": "mi cờ rô",
}
